;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gptel-commit" "20250726.1448"
  "Generate commit message with gptel."
  '((emacs "27.1")
    (gptel "0.9.8"))
  :url "https://github.com/lakkiy/gptel-commit"
  :commit "2b1063a01ab894ae5661bfffeb97331ad0cf2e3b"
  :revdesc "2b1063a01ab8"
  :keywords '("vc" "convenience")
  :authors '(("Liu Bo" . "liubolovelife@gmail.com"))
  :maintainers '(("Liu Bo" . "liubolovelife@gmail.com")))
